@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2000-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,15 +19,8 @@ Robots.txt parser.
 The robots.txt Exclusion Protocol is implemented as specified in
 http://www.robotstxt.org/wc/norobots-rfc.html
 """
-try:  # Python 3
-    from urllib import parse
-except ImportError:  # Python 2
-    import urllib as parse
-try:  # Python 3
-    from urllib.parse import urlparse
-except ImportError:  # Python 2
-    from urlparse import urlparse
 import time
+import urllib.parse
 
 import requests
 
@@ -39,11 +31,11 @@ __all__ = ["RobotFileParser"]
 ACCEPT_ENCODING = 'x-gzip,gzip,deflate'
 
 
-class RobotFileParser (object):
+class RobotFileParser:
     """This class provides a set of methods to read, parse and answer
     questions about a single robots.txt file."""
 
-    def __init__ (self, url='', session=None, proxies=None, auth=None):
+    def __init__(self, url='', session=None, proxies=None, auth=None, timeout=None):
         """Initialize internal entry lists and store given url and
         credentials."""
         self.set_url(url)
@@ -53,9 +45,10 @@ class RobotFileParser (object):
             self.session = session
         self.proxies = proxies
         self.auth = auth
+        self.timeout = timeout
         self._reset()
 
-    def _reset (self):
+    def _reset(self):
         """Reset internal flags and entry lists."""
         self.entries = []
         self.default_entry = None
@@ -64,8 +57,9 @@ class RobotFileParser (object):
         self.last_checked = 0
         # list of tuples (sitemap url, line number)
         self.sitemap_urls = []
+        self.encoding = None
 
-    def mtime (self):
+    def mtime(self):
         """Returns the time the robots.txt file was last fetched.
 
         This is useful for long-running web spiders that need to
@@ -76,21 +70,21 @@ class RobotFileParser (object):
         """
         return self.last_checked
 
-    def modified (self):
+    def modified(self):
         """Set the time the robots.txt file was last fetched to the
         current time."""
         self.last_checked = time.time()
 
-    def set_url (self, url):
+    def set_url(self, url):
         """Set the URL referring to a robots.txt file."""
         self.url = url
-        self.host, self.path = urlparse(url)[1:3]
+        self.host, self.path = urllib.parse.urlparse(url)[1:3]
 
-    def read (self):
+    def read(self):
         """Read the robots.txt URL and feeds it to the parser."""
         self._reset()
         kwargs = dict(
-            headers = {
+            headers={
                 'User-Agent': configuration.UserAgent,
                 'Accept-Encoding': ACCEPT_ENCODING,
             }
@@ -99,19 +93,27 @@ class RobotFileParser (object):
             kwargs["auth"] = self.auth
         if self.proxies:
             kwargs["proxies"] = self.proxies
+        if self.timeout:
+            kwargs["timeout"] = self.timeout
         try:
             response = self.session.get(self.url, **kwargs)
             response.raise_for_status()
             content_type = response.headers.get('content-type')
+            self.encoding = response.encoding
             if content_type and content_type.lower().startswith('text/plain'):
-                self.parse(response.iter_lines())
+                self.parse(response.iter_lines(decode_unicode=True))
             else:
                 log.debug(LOG_CHECK, "%r allow all (no text content)", self.url)
                 self.allow_all = True
         except requests.HTTPError as x:
             if x.response.status_code in (401, 403):
                 self.disallow_all = True
-                log.debug(LOG_CHECK, "%r disallow all (code %d)", self.url, x.response.status_code)
+                log.debug(
+                    LOG_CHECK,
+                    "%r disallow all (code %d)",
+                    self.url,
+                    x.response.status_code,
+                )
             else:
                 self.allow_all = True
                 log.debug(LOG_CHECK, "%r allow all (HTTP error)", self.url)
@@ -122,7 +124,7 @@ class RobotFileParser (object):
             self.allow_all = True
             log.debug(LOG_CHECK, "%r allow all (request error)", self.url)
 
-    def _add_entry (self, entry):
+    def _add_entry(self, entry):
         """Add a parsed entry to entry list.
 
         @return: None
@@ -133,7 +135,7 @@ class RobotFileParser (object):
         else:
             self.entries.append(entry)
 
-    def parse (self, lines):
+    def parse(self, lines):
         """Parse the input lines from a robot.txt file.
         We allow that a user-agent: line is not preceded by
         one or more blank lines.
@@ -150,7 +152,13 @@ class RobotFileParser (object):
             linenumber += 1
             if not line:
                 if state == 1:
-                    log.debug(LOG_CHECK, "%r line %d: allow or disallow directives without any user-agent line", self.url, linenumber)
+                    log.debug(
+                        LOG_CHECK,
+                        "%r line %d: allow or disallow directives without any"
+                        " user-agent line",
+                        self.url,
+                        linenumber,
+                    )
                     entry = Entry()
                     state = 0
                 elif state == 2:
@@ -167,66 +175,101 @@ class RobotFileParser (object):
             line = line.split(':', 1)
             if len(line) == 2:
                 line[0] = line[0].strip().lower()
-                line[1] = parse.unquote(line[1].strip())
+                line[1] = urllib.parse.unquote(line[1].strip(), self.encoding)
                 if line[0] == "user-agent":
                     if state == 2:
-                        log.debug(LOG_CHECK, "%r line %d: missing blank line before user-agent directive", self.url, linenumber)
+                        log.debug(
+                            LOG_CHECK,
+                            "%r line %d: missing blank line before"
+                            " user-agent directive",
+                            self.url,
+                            linenumber,
+                        )
                         self._add_entry(entry)
                         entry = Entry()
                     entry.useragents.append(line[1])
                     state = 1
                 elif line[0] == "disallow":
                     if state == 0:
-                        log.debug(LOG_CHECK, "%r line %d: missing user-agent directive before this line", self.url, linenumber)
-                        pass
+                        log.debug(
+                            LOG_CHECK,
+                            "%r line %d: missing user-agent directive before this line",
+                            self.url,
+                            linenumber,
+                        )
                     else:
                         entry.rulelines.append(RuleLine(line[1], False))
                         state = 2
                 elif line[0] == "allow":
                     if state == 0:
-                        log.debug(LOG_CHECK, "%r line %d: missing user-agent directive before this line", self.url, linenumber)
-                        pass
+                        log.debug(
+                            LOG_CHECK,
+                            "%r line %d: missing user-agent directive before this line",
+                            self.url,
+                            linenumber,
+                        )
                     else:
                         entry.rulelines.append(RuleLine(line[1], True))
                         state = 2
                 elif line[0] == "crawl-delay":
                     if state == 0:
-                        log.debug(LOG_CHECK, "%r line %d: missing user-agent directive before this line", self.url, linenumber)
-                        pass
+                        log.debug(
+                            LOG_CHECK,
+                            "%r line %d: missing user-agent directive before this line",
+                            self.url,
+                            linenumber,
+                        )
                     else:
                         try:
                             entry.crawldelay = max(0, int(line[1]))
                             state = 2
                         except (ValueError, OverflowError):
-                            log.debug(LOG_CHECK, "%r line %d: invalid delay number %r", self.url, linenumber, line[1])
-                            pass
+                            log.debug(
+                                LOG_CHECK,
+                                "%r line %d: invalid delay number %r",
+                                self.url,
+                                linenumber,
+                                line[1],
+                            )
                 elif line[0] == "sitemap":
                     # Note that sitemap URLs must be absolute according to
                     # http://www.sitemaps.org/protocol.html#submit_robots
                     # But this should be checked by the calling layer.
                     self.sitemap_urls.append((line[1], linenumber))
                 else:
-                    log.debug(LOG_CHECK, "%r line %d: unknown key %r", self.url, linenumber, line[0])
-                    pass
+                    log.debug(
+                        LOG_CHECK,
+                        "%r line %d: unknown key %r",
+                        self.url,
+                        linenumber,
+                        line[0],
+                    )
             else:
-                log.debug(LOG_CHECK, "%r line %d: malformed line %r", self.url, linenumber, line)
-                pass
+                log.debug(
+                    LOG_CHECK,
+                    "%r line %d: malformed line %r",
+                    self.url,
+                    linenumber,
+                    line,
+                )
         if state in (1, 2):
             self.entries.append(entry)
         self.modified()
         log.debug(LOG_CHECK, "Parsed rules:\n%s", str(self))
 
-    def can_fetch (self, useragent, url):
+    def can_fetch(self, useragent, url):
         """Using the parsed robots.txt decide if useragent can fetch url.
 
         @return: True if agent can fetch url, else False
         @rtype: bool
         """
-        log.debug(LOG_CHECK, "%r check allowance for:\n  user agent: %r\n  url: %r ...", self.url, useragent, url)
-        if not isinstance(useragent, str):
-            useragent = useragent.encode("ascii", "ignore")
-        if not isinstance(url, str):
-            url = url.encode("ascii", "ignore")
+        log.debug(
+            LOG_CHECK,
+            "%r check allowance for:\n  user agent: %r\n  url: %r ...",
+            self.url,
+            useragent,
+            url,
+        )
         if self.disallow_all:
             log.debug(LOG_CHECK, " ... disallow all.")
             return False
@@ -235,7 +278,10 @@ class RobotFileParser (object):
             return True
         # search for given user agent matches
         # the first match counts
-        url = parse.quote(urlparse(parse.unquote(url))[2]) or "/"
+        url = (
+            urllib.parse.quote(urllib.parse.urlparse(urllib.parse.unquote(url))[2])
+            or "/"
+        )
         for entry in self.entries:
             if entry.applies_to(useragent):
                 return entry.allowance(url)
@@ -246,7 +292,7 @@ class RobotFileParser (object):
         log.debug(LOG_CHECK, " ... agent not found, allow.")
         return True
 
-    def get_crawldelay (self, useragent):
+    def get_crawldelay(self, useragent):
         """Look for a configured crawl delay.
 
         @return: crawl delay in seconds or zero
@@ -257,7 +303,7 @@ class RobotFileParser (object):
                 return entry.crawldelay
         return 0
 
-    def __str__ (self):
+    def __str__(self):
         """Constructs string representation, usable as contents of a
         robots.txt file.
 
@@ -270,21 +316,21 @@ class RobotFileParser (object):
         return "\n\n".join(lines)
 
 
-class RuleLine (object):
+class RuleLine:
     """A rule line is a single "Allow:" (allowance==1) or "Disallow:"
     (allowance==0) followed by a path.
     """
 
-    def __init__ (self, path, allowance):
+    def __init__(self, path, allowance):
         """Initialize with given path and allowance info."""
         if path == '' and not allowance:
             # an empty value means allow all
             allowance = True
             path = '/'
-        self.path = parse.quote(path)
+        self.path = urllib.parse.quote(path)
         self.allowance = allowance
 
-    def applies_to (self, path):
+    def applies_to(self, path):
         """Look if given path applies to this rule.
 
         @return: True if pathname applies to this rule, else False
@@ -292,25 +338,25 @@ class RuleLine (object):
         """
         return self.path == "*" or path.startswith(self.path)
 
-    def __str__ (self):
+    def __str__(self):
         """Construct string representation in robots.txt format.
 
         @return: robots.txt format
         @rtype: string
         """
-        return ("Allow" if self.allowance else "Disallow")+": "+self.path
+        return ("Allow" if self.allowance else "Disallow") + ": " + self.path
 
 
-class Entry (object):
+class Entry:
     """An entry has one or more user-agents and zero or more rulelines."""
 
-    def __init__ (self):
+    def __init__(self):
         """Initialize user agent and rule list."""
         self.useragents = []
         self.rulelines = []
         self.crawldelay = 0
 
-    def __str__ (self):
+    def __str__(self):
         """string representation in robots.txt format.
 
         @return: robots.txt format
@@ -322,7 +368,7 @@ class Entry (object):
         lines.extend([str(line) for line in self.rulelines])
         return "\n".join(lines)
 
-    def applies_to (self, useragent):
+    def applies_to(self, useragent):
         """Check if this entry applies to the specified agent.
 
         @return: True if this entry applies to the agent, else False.
@@ -339,7 +385,7 @@ class Entry (object):
                 return True
         return False
 
-    def allowance (self, filename):
+    def allowance(self, filename):
         """Preconditions:
         - our agent applies to this entry
         - filename is URL decoded
@@ -354,5 +400,10 @@ class Entry (object):
             if line.applies_to(filename):
                 log.debug(LOG_CHECK, " ... rule line %s", line)
                 return line.allowance
-        log.debug(LOG_CHECK, " ... no rule lines of %s applied to %s; allowed.", self.useragents, filename)
+        log.debug(
+            LOG_CHECK,
+            " ... no rule lines of %s applied to %s; allowed.",
+            self.useragents,
+            filename,
+        )
         return True
